@@ -14,17 +14,17 @@ import collections
 import datetime
 import os
 
-from typing import cast, Any, Dict, List, Optional, Set
+from typing import Any, Dict, List, Optional, Set, cast
 
 import packaging.version
 import semantic_version
-import yaml
 
 from .config import ChangelogConfig
-from .fragment import load_fragments, ChangelogFragment
+from .fragment import ChangelogFragment, load_fragments
 from .logger import LOGGER
-from .plugins import load_plugins, PluginDescription
+from .plugins import PluginDescription, load_plugins
 from .utils import is_release_version
+from .yaml import load_yaml, store_yaml
 
 
 class FragmentResolver(metaclass=abc.ABCMeta):
@@ -131,8 +131,7 @@ class ChangesBase(metaclass=abc.ABCMeta):
         if data_override is not None:
             self.data = data_override
         elif os.path.exists(self.path):
-            with open(self.path, 'r') as meta_fd:
-                self.data = yaml.safe_load(meta_fd)
+            self.data = load_yaml(self.path)
         else:
             self.data = self.empty()
         self.ancestor = self.data.get('ancestor')
@@ -163,9 +162,7 @@ class ChangesBase(metaclass=abc.ABCMeta):
         """
         self.sort()
         self.data['ancestor'] = self.ancestor
-
-        with open(self.path, 'w') as config_fd:
-            yaml.safe_dump(self.data, config_fd, default_flow_style=False)
+        store_yaml(self.path, self.data)
 
     def add_release(self, version: str, codename: Optional[str], release_date: datetime.date):
         """
@@ -685,6 +682,11 @@ class ChangesData(ChangesBase):
             version_obj = self.version_constructor(version)
             if versions_after is not None and version_obj <= versions_after:
                 del self.data['releases'][version]
+                current_ancestor = self.ancestor
+                if current_ancestor is None:
+                    self.ancestor = version
+                elif self.version_constructor(current_ancestor) < self.version_constructor(version):
+                    self.ancestor = version
                 continue
             if versions_until is not None and version_obj > versions_until:
                 del self.data['releases'][version]
@@ -703,17 +705,21 @@ class ChangesData(ChangesBase):
         last = changes_datas[-1]
         data = ChangesBase.empty()
         ancestor = None
+        no_ancestor = False
         for changes in changes_datas:
             data['releases'].update(changes.data['releases'])
-            changes_ancestor = changes.ancestor
-            if changes_ancestor is not None:
-                if ancestor is None:
+            if not no_ancestor:
+                changes_ancestor = changes.ancestor
+                if changes_ancestor is None:
+                    no_ancestor = True
+                    ancestor = None
+                elif ancestor is None:
                     ancestor = changes.ancestor
                 else:
                     ancestor_ = last.version_constructor(ancestor)
                     changes_ancestor_ = last.version_constructor(changes_ancestor)
                     if ancestor_ > changes_ancestor_:
-                        ancestor = changes.ancestor
+                        ancestor = changes_ancestor
         data['ancestor'] = ancestor
         return ChangesData(last.config, last.path, data)
 
