@@ -14,11 +14,10 @@ import subprocess
 
 from typing import Any, Dict, List, Optional
 
-import yaml
-
 from .ansible import get_documentable_plugins
 from .config import CollectionDetails, PathsConfig
 from .logger import LOGGER
+from .yaml import load_yaml, store_yaml
 
 
 class PluginDescription:
@@ -215,6 +214,18 @@ def list_plugins_ansibledoc(paths: PathsConfig, plugin_type: str,
     return sorted(plugins_list.keys())
 
 
+def run_ansible_doc(paths: PathsConfig, plugin_type: str, plugin_names: List[str]) -> dict:
+    """
+    Runs ansible-doc to retrieve documentation for a given set of plugins in JSON format.
+
+    Plugins must be in FQCN for collections.
+    """
+    command = [paths.ansible_doc_path or 'ansible-doc', '--json', '-t', plugin_type]
+    command.extend(plugin_names)
+    output = subprocess.check_output(command)
+    return json.loads(output.decode('utf-8'))
+
+
 def load_plugin_metadata(paths: PathsConfig, plugin_type: str,
                          collection_name: Optional[str]) -> Dict[str, Dict[str, Any]]:
     """
@@ -225,16 +236,14 @@ def load_plugin_metadata(paths: PathsConfig, plugin_type: str,
     :arg collection_name: The name of the collection, if appropriate.
     """
     plugins_list = list_plugins_walk(paths, plugin_type, collection_name)
+    # WARNING: Do not switch to this before ansible-base is a requirement!
     # plugins_list = list_plugins_ansibledoc(paths, plugin_type, collection_name)
 
     result: Dict[str, Dict[str, Any]] = {}
     if not plugins_list:
         return result
 
-    command = [paths.ansible_doc_path or 'ansible-doc', '--json', '-t', plugin_type]
-    command.extend(plugins_list)
-    output = subprocess.check_output(command)
-    plugins_data = json.loads(output.decode('utf-8'))
+    plugins_data = run_ansible_doc(paths, plugin_type, plugins_list)
 
     for name, data in plugins_data.items():
         processed_data = jsondoc_to_metadata(paths, collection_name, plugin_type, name, data)
@@ -259,13 +268,11 @@ def load_plugins(paths: PathsConfig,
     plugins_data: Dict[str, Any] = {}
 
     if not force_reload and os.path.exists(plugin_cache_path):
-        with open(plugin_cache_path, 'r') as plugin_cache_fd:
-            plugins_data = yaml.safe_load(plugin_cache_fd)
-
-            if version != plugins_data['version']:
-                LOGGER.info('version {} does not match plugin cache version {}',
-                            version, plugins_data['version'])
-                plugins_data = {}
+        plugins_data = load_yaml(plugin_cache_path)
+        if version != plugins_data['version']:
+            LOGGER.info('version {} does not match plugin cache version {}',
+                        version, plugins_data['version'])
+            plugins_data = {}
 
     if not plugins_data:
         LOGGER.info('refreshing plugin cache')
@@ -288,8 +295,7 @@ def load_plugins(paths: PathsConfig,
                 if plugin['namespace'] is None:
                     del plugin['namespace']
 
-        with open(plugin_cache_path, 'w') as plugin_cache_fd:
-            yaml.safe_dump(plugins_data, plugin_cache_fd, default_flow_style=False)
+        store_yaml(plugin_cache_path, plugins_data)
 
     plugins = PluginDescription.from_dict(plugins_data['plugins'])
 
